# PyGTK Shell 1.90.1 To Do List

Felix Rabe
`<public@felixrabe.textdriven.com>`

## Things that need to be done soon

- Find / submit bug report about `gtk.window_list_toplevels()` returning windows that are not toplevel windows.

## Things that can wait

- Automate the process of pushing out releases.

- Improve the AsciiDoc XHTML to make the website more navigatable.

- Find a way (write a Python plugin) to reformat blocks of text in an intelligent and easy-to-use way using GEdit such that Documentation/*.txt remain easy on the eyes without too much effort.

## Release checklist

- Version number

  - Increase `PyGTKShell.Core.pygtkshell_version` (here represented as `<X.Y.Z>`)

- Website preparation

  - Update `Documentation/index.txt`

  - Update `Documentation/tutorial.txt` if necessary

  - Check for version and date glitches

  - Run `Documentation/mkdoc.sh`

  - FR: Run `./.rsync-exec-pygtk-shell-web-local.sh`

  - Look at `index.html`: check links etc.

  - Run `git-commit -a` (on the appropriate branch)

- Source (tar.gz)

  - Run `./setup.py sdist`

  - Extract `dist/pygtk-shell-<X.Y.Z>.tar.gz` to `/tmp`

  - Test the package

  - Run `mkdir <website>/pygtk-shell/releases/<X.Y.Z>`

  - Run `cp dist/pygtk-shell-<X.Y.Z>.tar.gz <website>/pygtk-shell/releases/<X.Y.Z>`

- Git repository preparation

  - Run `git-tag "v<X.Y.Z>"` (note the `v` character)

  - Run `git-update-server-info`

  - FR: Run `./.rsync-exec-pygtk-shell-web-local.sh`

- FR: Website / Git repository upload

- Git repository test

  - Clone to `/tmp` as described in the installation instructions

  - Test the repository for currency

- Announce the release

Place | Maintainer
--- | ---
http://felixrabe.textdriven.com/pygtk-shell/ | FR
PyGTK (mailing list) | FR
http://freshmeat.net/ | FR
http://www.gnomefiles.org/ | FR
Python Cheese Shop (PyPI) | FR (TODO)
http://linux.softpedia.com/ | FR (sometimes)
http://del.icio.us/ | ???
http://www.linuxlinks.com/ | ???